@@ -1,5 +1,9 @@
 import typer
 
+import os
+pwd = os.getcwd()
+os.system('export PYTHONPATH="${PYTHONPATH}:'+pwd+'"')
+
 import wifi
 import bt
 import util
